```{mermaid}
flowchart TD
 node1["schema"]
 node2["check_cv"]
 node3["data\samples.dvc"]
 node3-->node2
 node4["binarized_preview"]
 node5["contours"]
 node6["data\rois.dvc"]
 node7["data\sources.dvc"]
 node8["fill"]
 node9["filled_preview"]
 node10["gray_preview"]
 node5-->node8
 node6-->node4
 node7-->node4
 node7-->node5
 node7-->node8
 node7-->node9
 node7-->node10
 node8-->node9
 node11["data\examples.dvc"]
```
